@@ -343,7 +343,7 @@ def map_all_protrusion_indices(psaia_dir, psaia_config_file, pdb_dataset, pkl_da
     produced_keys = [db.get_pdb_code(x) for x in produced_filenames]
     work_keys = [key for key, pdb_code in zip(requested_keys, requested_pdb_codes) if pdb_code not in produced_keys]
     format_pdb_code_for_inputs = lambda pdb_code, source_type: pdb_code[1:3] \
-        if source_type.lower() in ['db5', 'input'] \
+        if source_type.lower() in ['input'] \
         else pdb_code.upper()
     if source_type.lower() == 'rcsb' or source_type.lower() == 'casp_capri':
         work_filenames = [os.path.join(pdb_dataset, db.get_pdb_code(work_key)[1:3], work_key)
